##
##  cbor.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2025 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_cbor      10.0.3
%define       V_cbor_snap 20250623

#   package information
Name:         cbor
Summary:      Concise Binary Object Representation
URL:          http://cbor.io/
Vendor:       Carsten Bormann et al.
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Libraries
License:      MIT
Version:      %{V_cbor}
Release:      20250623

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/cbor/cbor-%{V_cbor}-%{V_cbor_snap}.tar.gz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, node-openpkg
PreReq:       OpenPKG, openpkg >= 20160101, node, git

%description
    The Concise Binary Object Representation (CBOR) is a data format
    whose design goals include the possibility of extremely small code
    size, fairly small message size, and extensibility without the need
    for version negotiation.

%track
    prog cbor:release = {
        version   = %{V_cbor}
        url       = https://github.com/hildjj/node-cbor/releases
        regex     = tree/v(__VER__)
    }
    prog cbor:snapshot = {
        version   = %{V_cbor_snap}
        url       = http://download.openpkg.org/components/versioned/cbor/
        regex     = cbor-\d+\.\d+\.\d+-(\d+)\.tar\.gz
    }

%prep
    %setup -q -c

%build
    rm -rf node_modules/cbor/src
    rm -rf node_modules/cbor/man_src
    rm -rf node_modules/cbor/test
    rm -f  node_modules/cbor/Gruntfile.js
    rm -f  node_modules/cbor/coffeelint.json
    %{l_prefix}/bin/node-openpkg squeeze
    %{l_shtool} subst \
        -e 's;#!/usr/bin/env node;#!%{l_prefix}/bin/node;g' \
        node_modules/cbor/bin/*

%install
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin \
        $RPM_BUILD_ROOT%{l_prefix}/lib/cbor
    %{l_prefix}/bin/node-openpkg install \
        %{l_prefix}/lib/cbor/
    for prg in node_modules/cbor/bin/*; do
        name=`echo $prg | sed -e 's;.*/;;'`
        echo "$name"
        (   echo "#!/bin/sh"
            echo "NODE_PATH=%{l_prefix}/lib/cbor; export NODE_PATH"
            echo "exec %{l_prefix}/lib/cbor/cbor/bin/$name \${1+\"\$@\"}"
        ) >$name.sh
        %{l_shtool} install -c -m 755 \
            $name.sh $RPM_BUILD_ROOT%{l_prefix}/bin/$name
    done
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

